# CHANGELOG

<!-- version list -->

## v1.1.0 (2026-03-20)

### Features

- Add agent() context manager and refactor agentic_session to dual-style
  ([`a32abc4`](https://github.com/Kelet-ai/python-sdk/commit/a32abc43bb8851b40be00afae8319625a12c24ab))


## v1.0.0 (2026-03-07)

- Initial Release

## v1.0.0 (2026-03-07)

- Initial Release
